==> gmsh_1.60.1.orig.tar.gz: gmsh-1.60.1/Graphics/Iso.h <==
#ifndef _ISO_H_
#define _ISO_H_

// Copyright (C) 1997-2005 C. Geuzaine, J.-F. Remacle
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA.
// 
// Please report all bugs and problems to <gmsh@geuz.org>.

#include "Views.h"

void CutTriangle(double *X, double *Y, double *Z, double *Val,
		 double V1, double V2, double *Xp, double *Yp, double *Zp, 
		 int *nb, double *value);

void CutLine(double *X, double *Y, double *Z, double *Val,
	     double V1, double V2, double *Xp, double *Yp, double *Zp,
	     int *nb, double *value);

void IsoLine(Post_View *View, double *X, double *Y, double *Z, 
	     double *Val, double V);

void IsoTriangle(Post_View *View, double *X, double *Y, double *Z,
		 double *Val, double V);

void IsoSimplex(Post_View *View, int preproNormals, 
		double *X, double *Y, double *Z, double *Val, double V,
		unsigned int color);
  
#endif

==> gmsh_1.61.3.orig.tar.gz: gmsh-1.61.3/Graphics/Iso.h <==
#ifndef _ISO_H_
#define _ISO_H_

// Copyright (C) 1997-2005 C. Geuzaine, J.-F. Remacle
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA.
// 
// Please report all bugs and problems to <gmsh@geuz.org>.

#include "Views.h"

void CutTriangle(double *X, double *Y, double *Z, double *Val,
		 double V1, double V2, double *Xp, double *Yp, double *Zp, 
		 int *nb, double *value);

void CutLine(double *X, double *Y, double *Z, double *Val,
	     double V1, double V2, double *Xp, double *Yp, double *Zp,
	     int *nb, double *value);

void IsoLine(Post_View *View, double *X, double *Y, double *Z, 
	     double *Val, double V);

void IsoTriangle(Post_View *View, 
		 double *X, double *Y, double *Z, double *Val, double V,
		 unsigned int color);

void IsoSimplex(Post_View *View, int preproNormals, 
		double *X, double *Y, double *Z, double *Val, double V,
		unsigned int color);
  
#endif
